diff --git a/Examples/FeatureExtraction/ExtractSegmentsByStepsExample.cxx b/Examples/FeatureExtraction/ExtractSegmentsByStepsExample.cxx
index 06786c9bc0faff9576162dc4c6381b82403c065d..80142b5245145ec6c5193268d697dadeb1a97425 100644
--- a/Examples/FeatureExtraction/ExtractSegmentsByStepsExample.cxx
+++ b/Examples/FeatureExtraction/ExtractSegmentsByStepsExample.cxx
@@ -87,7 +87,7 @@ int main( int argc, char * argv[] )
   // Software Guide : BeginCodeSnippet
   //>FIXME itk::image-->OTB
   typedef itk::Image< InternalPixelType,  2 >   InternalImageType;
-  typedef otb::Image< OutputPixelType,  2 >   OutputImageType;
+  typedef itk::Image< OutputPixelType,  2 >   OutputImageType;
   // Software Guide : EndCodeSnippet
 
   typedef otb::LineSpatialObjectList	 LinesListType;
diff --git a/Examples/IO/ImageReadRegionOfInterestWrite.cxx b/Examples/IO/ImageReadRegionOfInterestWrite.cxx
index 6cb54d6621728d44c5f5353626a366750ce7cf35..9e7e6ffaebd9f70f9ce52ddbe3d68fb05ba9a625 100644
--- a/Examples/IO/ImageReadRegionOfInterestWrite.cxx
+++ b/Examples/IO/ImageReadRegionOfInterestWrite.cxx
@@ -79,9 +79,9 @@ int main( int argc, char ** argv )
   typedef unsigned char        InputPixelType;
   typedef unsigned char        OutputPixelType;
   const   unsigned int        Dimension = 2;
-
-  typedef otb::Image< InputPixelType,  Dimension >    InputImageType;
-  typedef otb::Image< OutputPixelType, Dimension >    OutputImageType;
+//FIXME itk to otb image
+  typedef itk::Image< InputPixelType,  Dimension >    InputImageType;
+  typedef itk::Image< OutputPixelType, Dimension >    OutputImageType;
   // Software Guide : EndCodeSnippet
diff --git a/Code/Common/otbExtractROI.h b/Code/Common/otbExtractROI.h
index 100f38b755930b02b916261a136e4d254fdf589f..013e22678c7440f7098ef9b46736f111be405241 100755
--- a/Code/Common/otbExtractROI.h
+++ b/Code/Common/otbExtractROI.h
@@ -24,17 +24,17 @@ namespace otb
  *
  * Le Pixel peut etre de type simple ou alors un itk::RGBPixel, etc.
  * \note Ces classe est param�tr�e par le type de pixel des images d'entr�e et de sortie. Les images manipul�es dans cette classe 
  * sont de type "otb::Image".
  *
  */
 template <class TInputPixel, class TOutputPixel>
 class ITK_EXPORT ExtractROI:
-    public ExtractROIBase<otb::Image<TInputPixel,2> , otb::Image<TOutputPixel,2> >
+    public ExtractROIBase<itk::Image<TInputPixel,2> , itk::Image<TOutputPixel,2> >
 {
 public:
   /** Standard class typedefs. */
   typedef ExtractROI         Self;
-  typedef ExtractROIBase<otb::Image<TInputPixel,2> , otb::Image<TOutputPixel,2> >  Superclass;
+  typedef ExtractROIBase<itk::Image<TInputPixel,2> , itk::Image<TOutputPixel,2> >  Superclass;
   typedef itk::SmartPointer<Self>  Pointer;
   typedef itk::SmartPointer<const Self>  ConstPointer;
 
@@ -24,17 +24,17 @@ namespace otb
  * Le Pixel peut etre de type simple ou alors un itk::RGBPixel, etc.
  * \note Ces classe est param�tr�e par le type de pixel des images d'entr�e et de sortie. Les images manipul�es dans cette classe 
- * sont de type "otb::Image".
+ * sont de type "itk::Image".
  *
  */